@@ -32,7 +32,7 @@ magenta=_magenta
 cyan=_cyan
 white=_white
 grey=_grey
-_version='N0Lib:0.0.7'
+_version='N0Lib:0.0.8'
 __N0Version__=''
 __SETVERSION__=False
 __DEBUG__=False 
@@ -552,6 +552,22 @@ def say(x,y,word,fColor=_white,clear=False,clearChar=' '):
             print('[SAY]:ERROR! Please use initGraphic().')
 def _setColor(fontColor,backColor=-1):
     return curses.color_pair(fontColor)
+def colorTest(limit=256):
+    retStr='0 '
+    retColorStr='1|0'
+    if limit!='$n0p':
+        limit=beNumber(limit,1024)
+        if limit>1024:
+            limit=1024
+        if limit=='$n0p' or limit<1:
+            consoleOut('color','Wrong number',_red,_white)
+            limit=256
+    else:
+        limit=256
+    for i in range(1,limit):
+        retColorStr+=','+str(len(str(i))+1)+'|'+str(i)
+        retStr+=str(i)+' '
+    consoleOut('color',retStr,'SPACE',colorStr=retColorStr,COLORFLITER=False)
 def followSay(word,fColor=_white):
     say(__OUTX__,__OUTY__,word,fColor)
 def echo(content,color=_white,STDOUT='$n0p'):
